@@ -286,6 +286,20 @@ class Generator:
             if part
         )
 
+    def tablesample_sql(self, expression):
+        this = self.sql(expression, "this")
+        numerator = self.sql(expression, "bucket_numerator")
+        denominator = self.sql(expression, "bucket_denominator")
+        field = self.sql(expression, "bucket_field")
+        field = f" ON {field}" if field else ""
+        bucket = f"BUCKET {numerator} OUT OF {denominator}{field}" if numerator else ""
+        percent = self.sql(expression, "percent")
+        percent = f"{percent} PERCENT" if percent else ""
+        rows = self.sql(expression, "rows")
+        rows = f"{rows} ROWS" if rows else ""
+        size = self.sql(expression, "size")
+        return f"{this} TABLESAMPLE({bucket}{percent}{rows}{size})"
+
     def tuple_sql(self, expression):
         return f"({self.expressions(expression, flat=True)})"
 
